.. google_translate documentation master file, created by
   sphinx-quickstart on Mon Jul 25 17:59:23 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Contents
========

.. toctree::
    :maxdepth: 2

    self
    intro
    examples
    contribute
    api
    cmdline


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
